@@ -192,7 +192,7 @@ class IveoDevice(Device):
     def moveDown(self):
         self.automaticIveoCommand(CommandTypeIveo.DRIVEDOWN)
     
-    def moveUpIveo(self):
+    def moveUp(self):
         self.automaticIveoCommand(CommandTypeIveo.DRIVEUP)
     
     def moveIntermediatePosition1(self):
